import { existsSync, mkdirSync, writeFile } from "fs";
import path from "path";
import chalk from "chalk";
import { generateSpringModel } from "../../generators/templates/spring_model_template.js";
import { dolphMsg } from "../../helpers/messages.js";
const createModelDirectory = (componentName) => {
    const projectRoot = path.join(process.cwd());
    const userModelPath = path.join(projectRoot, `/src/${componentName}`);
    if (!existsSync(userModelPath)) {
        mkdirSync(userModelPath);
    }
};
const findModelDirectory = (componentName) => {
    const rootDir = process.cwd();
    const possibleDirs = [`src/${componentName}`];
    const modelDir = possibleDirs.find((dir) => existsSync(path.join(rootDir, dir)));
    return modelDir ? path.join(rootDir, modelDir) : null;
};
export const generateSpringModelFile = async (componentName, modelDir, isMongo, isMySql) => {
    await writeFile(modelDir, generateSpringModel(componentName, isMongo, isMySql), (error) => {
        if (error) {
            dolphMsg.errorRed(error.toString());
        }
    });
};
export const generateModel = async (name, isMongo, isMySql) => {
    if (!name)
        dolphMsg.errorRed("model extension or name is required! 🤨");
    let modelDir = findModelDirectory(name);
    if (!modelDir) {
        createModelDirectory(name);
        modelDir = findModelDirectory(name);
    }
    const modelFilePath = path.join(modelDir + `/${name}.model.ts`);
    try {
        generateSpringModelFile(name, path.join(modelFilePath), isMongo, isMySql);
    }
    catch (e) {
        dolphMsg.errorRed(e);
    }
    dolphMsg.info(`${chalk.blue(`${name}.model.ts`)} generated successfully for ${chalk.blue(`${name}`)} component.`);
};
